@@ -13,7 +13,7 @@ log = logging.getLogger(__name__)
 
 
 sys.argv =[sys.argv[0],'C://Users/zhangfan36/Desktop/简历/证件照.jpg']
-if __name__=='__main__':
+def main():
     # 准备好必要参数
     beautiful_url='https://api-cn.faceplusplus.com/facepp/v2/beautify'
     api_key='kTseH9TtSH_Hody8k15fhkRzyXpEuhmJ'
